@@ -1,21 +1,7 @@
 /*
-    Copyright 2008 Sascha Peilicke <sasch.pe@gmx.de>
+    SPDX-FileCopyrightText: 2008 Sascha Peilicke <sasch.pe@gmx.de>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #ifndef KIGO_GAMESCENE_H
@@ -47,12 +33,12 @@ class GameScene : public QGraphicsScene
     Q_OBJECT
 
 public:
-    explicit GameScene(Game *game, QObject *parent = 0);
+    explicit GameScene(Game *game, QObject *parent = nullptr);
 
-signals:
+Q_SIGNALS:
     void cursorPixmapChanged(const QPixmap &);
 
-public slots:
+public Q_SLOTS:
     void resizeScene(int width, int height);
     void showLabels(bool show);
     void showHint(bool show);
@@ -61,7 +47,7 @@ public slots:
     void showPlacementMarker(bool show);
     void showTerritory(bool show);
 
-private slots:
+private Q_SLOTS:
     void updateStoneItems();
     void updateHintItems();
     void updateTerritoryItems();
@@ -70,9 +56,9 @@ private slots:
     void themeChanged();
 
 private:
-    void mouseMoveEvent(QGraphicsSceneMouseEvent *event) Q_DECL_OVERRIDE;
-    void mousePressEvent(QGraphicsSceneMouseEvent *event) Q_DECL_OVERRIDE;
-    void drawBackground(QPainter *painter, const QRectF &) Q_DECL_OVERRIDE;
+    void mouseMoveEvent(QGraphicsSceneMouseEvent *event) override;
+    void mousePressEvent(QGraphicsSceneMouseEvent *event) override;
+    void drawBackground(QPainter *painter, const QRectF &) override;
 
     Game *m_game;                           ///< Go game
 
